<?php
/**
 * @package SubsriberMagnet 2.0
*/

class SubsriberMagnetCfg{
    public static $xml; 
    public static $request_key; 
    private $_params = array();
    private static $instance;
    
    private function __construct(){
        $this->_loadSettings();
    }
    private function __clone(){}
        
    public static function in(){
       if(!isset(self::$instance)) {
                self::$instance = new SubsriberMagnetCfg();
        }
        return self::$instance;
    }
    
    public function set($name, $value){
        $this->_params[$name] = $value;
    }
    
    public function get($name){
        return $this->_params[$name];
    }
    
    public function toArray(){
        return $this->_params;
    } 
    
    private function _loadSettings(){
        if(!self::$xml){
            self::$xml =  simplexml_load_file(dirname(__FILE__).'/secretpage_settings.xml');
        }
        
        foreach(self::$xml->config->field as $item){
            $attr = $item->attributes();
            $this->set($attr->name . '', $attr->value . ''); 
        }
        $this->set('version',self::$xml->version . '');        
        
        if($this->get('wmode') != 'normal'){
           $this->set('wmode','iframe');
        }
        $RunIPS = $this->get('run_ips');  
        if(!empty($RunIPS)){
            $this->set('run_ips', explode(',', $RunIPS));
        }
        $this->set('request_key',self::$request_key); 
        $this->set('home_url', $this->_home_url());
    }   
    
    private function _home_url(){
        $url = $this->get('home');
        $url = (!empty($url)) ? $url : '';
        $url = 'http://'. $_SERVER['SERVER_NAME'] .'/'. $url; 
        return $url;
    }     
    
}


class SubsriberMagnetForm{
    
    private $_form;
    private $_wrapper = 'wrapper.tpl'; // Обертка для формы, в случае изолированного запуска
    private $_cfg; 
    
    /**
     * @param instance SubsriberMagnetCfg
    */
    public function __construct($config){
        $this->_cfg = $config;
    }
    
    public function load(){ 
        return ($this->_cfg->get('wmode') == 'normal') ? $this->normal() : $this->isolate(); 
    }
    
    public function is_frame_load(){
        return (strpos($_SERVER['REQUEST_URI'], 'wmodeframe' . $this->_cfg->get('request_key')));
    }
    
    public function onLoadFrameForm(){
        $wrapper = file_get_contents(SMAGNET_ASSETS_PATH . $this->_wrapper);
        
        $good_alert = (defined('GOOD_ALERT_JS') && defined('GOOD_ALERT_CSS')) ? GOOD_ALERT_JS . GOOD_ALERT_CSS : '';
        
        $fields = array(
             'title'    => $this->_cfg->get('title') 
            ,'form'     => $this->_getPluginHtml()
            ,'style'    => $this->_getPluginCss()
            ,'js'       => $this->_getPluginJs()
            ,'jquery'   => $this->_home() . $this->_cfg->get('assets_url') . '/js/jquery.js'
            ,'home'     => $this->_cfg->get('home_url')
            ,'goodalert'=> $good_alert
        ); 

        return self::_parseTemplate($fields, $wrapper);
    }
    
    public function normal(){

        $js1  = dirname(SMAGNET_ASSETS_PATH) . '/jquery.tpl';
        $js1  = self::_parseTemplate(array('jquery' => $this->_cfg->get('assets_url') . '/js/jquery.js'), file_get_contents($js1));
        
        $out  = $this->_getPluginCss();
        $out .= $this->_getPluginHtml();
        $out .= $js1;
        $out .= '<script type="text/javascript" src="'.$this->_getPluginJs().'"></script>';
        
        return $out;
    }  
    
    public function isolate(){
        $uri = $_SERVER['REQUEST_URI'];
        $query  =  (strpos($uri, '?') !== false) ? $uri . '&wmodeframe' : $uri .'/?wmodeframe';
        $query .=  $this->_cfg->get('request_key');
        
        $url = 'http://' . $_SERVER['SERVER_NAME'] . $query;    
        
        $js  = file_get_contents(SMAGNET_ASSETS_PATH . 'ifr.tpl'); 
        $js  = self::_parseTemplate(array('url' => $url), $js);
        return $js;
    }    
    
    private function _getPluginJs(){
        return $this->_home() . $this->_cfg->get('assets_url') . 'js/js.js?v=' . $this->_cfg->get('version');
    }
    
    private function _getPluginCss(){
       $_style = $this->_cfg->get('style');

       $style  =  $this->_home() . $this->_cfg->get('assets_url') . 'styles/'.$_style.'/css.css';
       $return = '<link rel="stylesheet" href="'. $style .'" />';

       $style   = $this->_home() . $this->_cfg->get('assets_url') . 'styles/'.$_style.'/css_ie.css';
       $return .= '<!--[if lt IE 9]><link rel="stylesheet" href="'. $style .'" /><![endif]-->';
       return $return;
         
    }  
    
    private function _getPluginHtml(){
        $_options = $this->_cfg->toArray();
        $_keys = array_keys($_options);

        foreach($_keys as $key){
             if(strpos($key, 'smart_api') === true) continue;
             $keys[$key] = $this->_cfg->get($key);
        }
        
        $keys['loading_img'] = $this->_home() . $this->_cfg->get('assets_url') . 'styles/' . $this->_cfg->get('style') . '/preloader.gif';
        $keys['action'] = ''; 
        $template = file_get_contents(SMAGNET_ASSETS_PATH . 'template.tpl'); 
        
        $template = self::_parseTemplate($keys, $template);
        $template = self::_compactHtml($template);
  
        return $template;
    }  
    
    private function _home(){
        return '//' . $_SERVER['SERVER_NAME'] . '/' . $this->_cfg->get('home') . '/';
    } 
      
    private static function _compactHtml($string){
       $string = preg_replace("/\s+/", ' ', $string);
       $string = str_replace('> <', '><', $string);   
       return $string;     
    }    
    
    private static function _parseTemplate($keys, $template){
        foreach($keys as $key=>$v){
             $template = str_replace('{{'.$key.'}}', $v, $template);
        }        
        return $template;
    }        
    
}

